/**
 * Copyright (C) 2008 Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/

package org.ow2.orchestra.facade.data.runtime;

import org.ow2.orchestra.facade.data.AbstractData;
import org.ow2.orchestra.facade.data.def.ProcessDefinitionData;
import org.ow2.orchestra.facade.runtime.ActivityState;
import org.ow2.orchestra.facade.uuid.ProcessInstanceUUID;

/**
 * Data that belongs to a process instance.
 *
 * @author Gael Lalire, Guillaume Renault
 */
public class ProcessInstanceData extends AbstractData {

  private static final long serialVersionUID = -2276795072106178301L;

  private final ProcessDefinitionData processDefinitionData;

  private final ProcessInstanceUUID uuid;

  /**
   * The state of the instance.
   */
  private final ActivityState state;

  public ProcessInstanceData(
      final ProcessDefinitionData processDefinitionData,
      final ProcessInstanceUUID uuid,
      final ActivityState state) {
    this.processDefinitionData = processDefinitionData;
    this.uuid = uuid;
    this.state = state;
  }

  /**
   * @return the processDefinitionData
   */
  public ProcessDefinitionData getProcessDefinitionData() {
    return this.processDefinitionData;
  }

  /**
   * @return the uuid
   */
  public ProcessInstanceUUID getUUID() {
    return this.uuid;
  }

  /**
   * Returns the state of the instance.
   *
   * @return The state of the instance.
   */
  public ActivityState getState() {
    return this.state;
  }

}
